Seitzman 2018 atlas


Notes
-----
300 ROI coordinates in cortical, subcortical and cerebellar regions.

"Here, we apply a winner-take-all partitioning method to resting-state fMRI data and careful consideration of
anatomy to generate novel functionally-constrained ROIs in the thalamus, basal ganglia, amygdala, hippocampus, and
cerebellum. We validate these ROIs in three datasets via several anatomical and functional criteria, including known
anatomical divisions and functions, as well as agreement with existing literature.
Further, we demonstrate that combining these ROIs with established cortical ROIs recapitulates and extends
previously described functional network organization." (Seitzman et. al, 2018, 2020)



Content
-------
    :"rois": Coordinates of 300 ROIs in MNI space
    :"radius": Radius of each ROI in mm
    :"networks": Network names
    :"regions": Region names

References
----------
For more information see:
https://greenelab.wustl.edu/data_software

ROI coordinates downloaded from:
https://wustl.box.com/s/twpyb1pflj6vrlxgh3rohyqanxbdpelw

Paper:
Seitzman, B. A., Gratton, C., Marek, S., Raut, R. V., Dosenbach, N. U. F., Schlaggar, B. L., et al. (2020).
A set of functionally-defined brain regions with improved representation of the subcortex and cerebellum.
NeuroImage, 206, 116290. http://doi.org/10.1016/j.neuroimage.2019.116290

Preprint:
Seitzman et al. (2018). http://doi.org/10.1101/450452
